@@ -144,9 +144,14 @@ class Accounts(Resource):
 
                 data["message"] = response_data.get("MessageDescription", "")
                 data["code"] = response_data.get("MessageCode", "-1111111")
-                data["reference"] = response_data.get("MessageReference", "")
                 data["balance"] = response_data.get("AvailableBalance", "")
 
+            elif super().get_bank_id() == super().EQUITY:
+
+                data["message"] = response_data.get("message", "")
+                data["code"] = response_data.get("code", -1111111)
+                data["balance"] = response_data.get("data", {}).get("balances",[])[0].get("amount",-1)
+
         elif super().get_operation() == super().MINI_STATEMENT or super().get_operation() == super().ACCOUNT_TRANSACTIONS:
              
             if super().get_bank_id() == super().COOP:
@@ -205,11 +210,16 @@ class Accounts(Resource):
 
                 data["message"] = response_data.get("MessageDescription", "")
                 data["code"] = response_data.get("MessageCode", "-1111111")
+                data["account_name"] = ""
 
             elif super().get_bank_id() == super().EQUITY:
 
                 data["message"] = response_data.get("message", "")
                 data["code"] = f'{response_data.get("code", -111111)}'
+                data["account_name"] = ""
+                customer = response_data.get("data", {}).get("customer", [])
+                if len(customer) > 0:
+                    data["account_name"] = customer[0].get("name", "")
 
         elif super().get_operation() == super().FULL_STATEMENT:
 
