@@ -1,6 +1,6 @@
 from bank_sync.Resources.resource import Resource
 from bank_sync.APIs.utils.generate_code import get_code
-
+from datetime import date
 
 class Payments(Resource):
 
@@ -90,7 +90,7 @@ class Payments(Resource):
 
                     data["Destinations"].append(
                         {
-                            "ReferenceNumber": f'{get_code(length=14)}',
+                            "ReferenceNumber": payload.get("transfer", {}).get("reference", None),
                             "AccountNumber": destinations[i].get("account_number", None),
                             "BankCode": payload.get("transfer", {}).get("bank_code", None),
                             "BranchCode": payload.get("transfer", {}).get("branch_code", None),
@@ -127,7 +127,7 @@ class Payments(Resource):
                             "type": "InternalFundsTransfer",
                             "amount": f'{destination.get("amount",None)}',
                             "currencyCode": payload.get("transfer", {}).get("currency_code", None),
-                            "reference": f'{get_code(length=14)}',
+                            "reference": payload.get("transfer", {}).get("reference", None),
                             "date": payload.get("transfer", {}).get("date", None),
                             "description": payload.get("transfer", {}).get("description", ""),
                         }
@@ -187,7 +187,7 @@ class Payments(Resource):
 
                     data["Destinations"].append(
                         {
-                            "ReferenceNumber": f'{get_code(length=14)}',
+                            "ReferenceNumber": payload.get("transfer", {}).get("reference", None),
                             "MobileNumber": f'{destinations[i].get("mobile_number",None)}',
                             "Amount": destinations[i].get("amount", None),
                             "Narration": payload.get("transfer", {}).get("description", "")
@@ -222,7 +222,7 @@ class Payments(Resource):
                             "type": "MobileWallet",
                             "amount": f'{destination.get("amount",None)}',
                             "currencyCode": payload.get("transfer", {}).get("currency_code", None),
-                            "reference": f'{get_code(length=14)}',
+                            "reference": payload.get("transfer", {}).get("reference", None),
                             "date": payload.get("transfer", {}).get("date", None),
                             "description": payload.get("transfer", {}).get("description", ""),
                         }
@@ -289,7 +289,7 @@ class Payments(Resource):
                             "type": "RTGS",
                             "amount": f'{destination.get("amount",None)}',
                             "currencyCode": payload.get("transfer", {}).get("currency_code", None),
-                            "reference": f'{get_code(length=14)}',
+                            "reference": payload.get("transfer", {}).get("reference", None),
                             "date": payload.get("transfer", {}).get("date", None),
                             "description": payload.get("transfer", {}).get("description", ""),
                         }
@@ -355,7 +355,7 @@ class Payments(Resource):
                             "type": "SWIFT",
                             "amount": f'{destination.get("amount",None)}',
                             "currencyCode": payload.get("transfer", {}).get("currency_code", None),
-                            "reference": f'{get_code(digits_only = True,length=13)}',
+                            "reference": payload.get("transfer", {}).get("reference", None),
                             "date": payload.get("transfer", {}).get("date", None),
                             "description": payload.get("transfer", {}).get("description", ""),
                             "chargeOption": "SELF"
@@ -424,7 +424,7 @@ class Payments(Resource):
 
                     data["Destinations"].append(
                         {
-                            "ReferenceNumber": f'{get_code(length=14)}',
+                            "ReferenceNumber": payload.get("transfer", {}).get("reference", None),
                             "AccountNumber": destinations[i].get("account_number", None),
                             "BankCode": payload.get("transfer", {}).get("bank_code", None),
                             "Amount": destinations[i].get("amount", None),
@@ -462,7 +462,7 @@ class Payments(Resource):
                             "type": "PesaLink",
                             "amount": f'{destination.get("amount",None)}',
                             "currencyCode": payload.get("transfer", {}).get("currency_code", None),
-                            "reference": f'{get_code(digits_only = True,length=12)}',
+                            "reference": payload.get("transfer", {}).get("reference", None),
                             "date": payload.get("transfer", {}).get("date", None),
                             "description": payload.get("transfer", {}).get("description", ""),
                         }
@@ -522,7 +522,7 @@ class Payments(Resource):
 
                     data["Destinations"].append(
                         {
-                            "ReferenceNumber": f'{get_code(length=14)}',
+                            "ReferenceNumber": payload.get("transfer", {}).get("reference", None),
                             "PhoneNumber": destinations[i].get("mobile_number", None),
                             "Amount": destinations[i].get("amount", None),
                             "TransactionCurrency": payload.get("transfer", {}).get("currency_code", None),
@@ -558,7 +558,7 @@ class Payments(Resource):
                             "type": "PesaLink",
                             "amount": f'{destination.get("amount",None)}',
                             "currencyCode": payload.get("transfer", {}).get("currency_code", None),
-                            "reference": f'{get_code(length=14)}',
+                            "reference": payload.get("transfer", {}).get("reference", None),
                             "date": payload.get("transfer", {}).get("date", None),
                             "description": payload.get("transfer", {}).get("description", ""),
                         }
@@ -594,11 +594,14 @@ class Payments(Resource):
         data = {}
 
         response_data = super().response()
+        data["payload"] = response_data.get("payload", {})
 
         if super().get_bank_id() == super().COOP:
 
             data["message"] = response_data.get("MessageDescription", "")
-            data["code"] = response_data.get("MessageCode", "-1111111")
+            data["code"] = int(response_data.get("MessageCode", -1111111))
+            data["date"] = response_data.get("MessageDateTime", date.today().strttime('%d/%m/%y %H:%M:%S'))
+            data["transaction_id"] = response_data.get("Destinations", {}).get("TransactionID", "")
 
             if 'MessageDescription' in response_data.keys():
                 if response_data.get("MessageDescription", "") == "Full Success":
@@ -607,7 +610,7 @@ class Payments(Resource):
                     data["message"] = response_data.get("MessageDescription", "")
 
             if 'MessageCode' in response_data.keys():
-                data["code"] = response_data.get("MessageCode", "-1111111")
+                data["code"] = int(response_data.get("MessageCode", -1111111))
 
             if 'messageDescription' in response_data.keys():
                 if response_data.get("messageDescription", "") == "Full Success":
@@ -616,12 +619,14 @@ class Payments(Resource):
                     data["message"] = response_data.get("messageDescription", "")
 
             if 'messageCode' in response_data.keys():
-                data["code"] = response_data.get("messageCode", "-1111111")
+                data["code"] = response_data.get("messageCode", -1111111)
 
         elif super().get_bank_id() == super().EQUITY:
             data["message"] = response_data.get("message", "")
-            data["code"] = f'{response_data.get("code", "-1111111")}'
-            data["reference"] = response_data.get("reference", "")
+            data["code"] = response_data.get("code", -1111111)
+            data["transaction_id"] = response_data.get("data", {}).get("transactionId", "")
+            data["date"] = response_data.get("date", date.today().strftime('%d/%m/%y %H:%M:%S'))
+            
             
         if bool(data):
             return data
